{% extends "decks/_layout_decks.html" %}

### PRESENTATION ###
{% block first_paragraph %}
    Il s'agit d'un deck basé sur les terrains, sur le développement du mana et un plan de jeu quasi inarrêtable par des interactions de l'adversaire.  La force des jeux Land est aussi leur faiblesse : leur immobilisme peut les mener à leur perte face à des decks Contrôle ou Tempo.
{% endblock %}
{% block second_paragraph %}
    Le plan de jeu {{ valakutthemoltenpinnacle }} est le moyen principal de gagner la partie. C'est une stratégie lente qui est accélérée par les différentes capacités de Soul of Windgrace.
{% endblock %}
{% block third_paragraph %}
    Un grand merci à bitzelberg qui a accepté de nous donner sa liste pour la jouer dans cette série.
{% endblock %}


### LISTES ###
{% block liste %}
{{ decklist("https://www.moxfield.com/decks/0zxZ1ax2e0a3phLIfobZjA", "Decklist par bitzelberg") }}
{% endblock %}


### MATCHS ###
{% block matchs %}
{{ match.card2("/matchs/raffine-vs-soul-of-windgrace", "Raffine affronte un gérénal de Dominaria United. Quel est l'impact des sorties sur la stabilité d'un deck ?") }}
{% endblock %}


### PILOTES ###
{% block pilotes %}
<div class="col-sm-4">
    {{ pilote.spigushe(played_on="4 octobre 2022") }}
</div>
{% endblock %}
