{% extends "matchs/_layout_matchs.html" %}

### PRESENTATION ###
{% block analyse %}
    Les stratégies respectives de chaque deck sont très claires et représentent
    une situation courante de
    {{ link("/articles/classifier-un-deck", "la roue des archétypes") }}.
    Le deck dit <em>tempo</em>, Raffine, a l'ascendant structurel sur le deck
    dit <em>contrôle</em>, Tivit. Raffine va chercher à développer une menace
    assez tôt et à la défendre des différentes gestions de Tivit. C'est donc
    sur la diversité et la quantité des interactions qu'aura Tivit que Raffine
    sera plus ou moins tranquille dans sa partie.
{% endblock %}


### JOUEURS ###
{% set joueur1 = "Spigushe" %}
{% set joueur2 = "Domino" %}

### VIDEO ###
{% set youtube = "https://www.youtube.com/embed/-vIGz2GvEuk" %}
{% set date = "17 mai 2022" %}

### LEGENDE ###
{% block pilote1 %}{{ pilote.spigushe() }}{% endblock %}
{% block deck1 %}{{ deck.card("/decks/raffine-scheming-seer") }}{% endblock %}
{% block deck2 %}{{ deck.card("/decks/tivit-seller-of-secrets") }}{% endblock %}
{% block pilote2 %}{{ pilote.domino() }}{% endblock %}
