{% extends "decks/_layout_decks.html" %}

### PRESENTATION ###
{% block first_paragraph %}
    Il s'agit d'un deck agressif dont l'objectif est de remplir le champ de
    bataille de créatures légendaires pour maximiser les dégâts de Yoshimaru.
{% endblock %}
{% block second_paragraph %}
    Sa valeur de mana très faible permet au deck, comme
    {{ link("/decks/isamaru-hound-of-konda") }}, de prendre le rôle de
    l'agresseur très rapidement et de manière assez définitive.
{% endblock %}
{% block third_paragraph %}
    L'ajout du rouge permet de maximiser le nombre de légendaires à un coût
    relativement faible et dont le potentiel destructeur est très élevé.
{% endblock %}


### LISTES ###
{% block liste %}
{{ decklist("https://www.moxfield.com/decks/jw13tkex7EyR6ytgNn4sjg", "Version Boros") }}
{{ decklist("https://www.moxfield.com/decks/QkIcUBSqfk-C-nebfMGS2Q", "Version Naya") }}
{% endblock %}


### MATCHS ###
{% block matchs %}
{{ match.card2("/matchs/gut-boros-vs-yoshimaru-boros", "Un duel d'agro boros, l'un cherche à agresser le plus rapidement possible, l'autre de développer un plan de jeu. Lequel remportera la victoire ?") }}
{{ match.card2("/matchs/leovold-vs-yoshimaru-naya", "Un match qui oppose un Yoshimaru prétendant au groupe des meilleurs decks contre le deck qui a gagné le Relic Fest #2 de début novembre") }}
{% endblock %}


### PILOTES ###
{% block pilotes %}
<div class="col-sm-4">
    {{ pilote.domino(played_on="27 septembre 2022") }}
</div>
<div class="col-sm-4">
    {{ pilote.askeladden(played_on="17 décembre 2022") }}
</div>
{% endblock %}
