{% extends "matchs/_layout_matchs.html" %}

### PRESENTATION ###
{% block analyse %}
    Le deck Beamtown Bullies permet d'allier les stratégies agressives et combo.
    L'opposition fournie par Aminatou, très souvent en décalé par rapport au
    problème posé, ne permet pas de résister aux deux stratégies si elles
    s'imbriquent. La présence d'une combo dans le deck Aminatou permet de
    grapiller quelques victoires mais cela ne sera pas suffisant. Le matchup
    est à l'avantage de Bullies.
{% endblock %}


### JOUEURS ###
{% set joueur1 = "threem" %}
{% set joueur2 = "Imperia86" %}

### VIDEO ###
{% set youtube = "https://www.youtube.com/embed/Brgby-YJzms" %}
{% set date = "10 mai 2022" %}

### LEGENDE ###
{% block pilote1 %}{{ pilote.threem() }}{% endblock %}
{% block deck1 %}{{ deck.card("/decks/aminatou-the-fateshifter") }}{% endblock %}
{% block deck2 %}{{ deck.card("/decks/the-beamtown-bullies") }}{% endblock %}
{% block pilote2 %}{{ pilote.imperia86() }}{% endblock %}
