{% extends "index.html" %}

{% block title %}
404 - Not Found
{% endblock %}

{% block banner %}
<div class="barrins-codex-banner">
    Page non trouvée
</div>
{% endblock %}

{% block article %}
<div class="col-8 mx-auto mt-6">
    <p class="text-center">La page que vous essayez d'atteindre n'existe pas.</p>
    <p class="text-center"><a href="{{ url('') }}" class="text-reset text-decoration-underline">Page d'accueil</a></p>
</div>
{% endblock %}
