<div id="matchCarousel" class="carousel slide col-md-8 ms-auto me-auto mb-4" data-bs-ride="carousel">
    <div class="carousel-indicators">
        {% for item in last_matchs -%}
        <button type="button" data-bs-target="#matchCarousel"
            data-bs-slide-to="{{ loop.index0 }}" {% if loop.index == 1 %}class="active"{% endif %}
            aria-current="true" aria-label="Match {{ all_matchs|length - loop.index0 }}">
        </button>
        {%- endfor %}
    </div>
    <div class="carousel-inner">
        {% for item in last_matchs -%}
        {% set lien = "img/"+item[1:]+".jpg" %}
        <div class="carousel-item {% if loop.index == 1 %}active{% endif %}">
            <img src="{{ url_for('static', filename=lien) }}" class="d-block w-100" alt="Match {{ all_matchs|length - loop.index0 }}">
            <div class="carousel-caption d-none d-md-block">
                <h5>{{ link(item) }}</h5>
            </div>
        </div>
        {%- endfor %}
    </div>
    <button class="carousel-control-prev" type="button" data-bs-target="#matchCarousel" data-bs-slide="prev">
        <span class="carousel-control-prev-icon" aria-hidden="true"></span>
        <span class="visually-hidden">Previous</span>
    </button>
    <button class="carousel-control-next" type="button" data-bs-target="#matchCarousel" data-bs-slide="next">
        <span class="carousel-control-next-icon" aria-hidden="true"></span>
        <span class="visually-hidden">Next</span>
    </button>
</div>
