{% extends "matchs/_layout_matchs.html" %}

### PRESENTATION ###
{% block analyse %}
    La version présentée de Kari Zev a plus de facilité à endosser la posture
    du deck contrôle. Cependant, le zoo proposé par Saskia permet de maintenir
    un flot de créatures attaquantes assez soutenu qui met en difficulté
    continuellement Kari Zev.
{% endblock %}


### JOUEURS ###
{% set joueur1 = "Spigushe" %}
{% set joueur2 = "Trotte" %}

### VIDEO ###
{% set youtube = "https://www.youtube.com/embed/C8qRYQMghi8" %}
{% set date = "2 décembre 2021" %}

### LEGENDE ###
{% block pilote1 %}{{ pilote.spigushe() }}{% endblock %}
{% block deck1 %}{{ deck.card("/decks/saskia-the-unyielding") }}{% endblock %}
{% block deck2 %}{{ deck.card("/decks/kari-zev-skyship-raider") }}{% endblock %}
{% block pilote2 %}{{ pilote.trotte() }}{% endblock %}
