{% extends "matchs/_layout_matchs.html" %}

### PRESENTATION ###
{% block analyse %}
    Dans cette configuration, Aminatou joue une version plus agressive
    qu'habituellement et a troqué ses sorts d'interaction pour des créatures.
    Dans un affrontement face à un deck contrôle et combo, cela dessert
    grandement le deck. Au final, comme toujours dans un match d'agro contre
    combo, c'est au pilote qui mettra fin à la partie que la victoire ira.
{% endblock %}


### JOUEURS ###
{% set joueur1 = "Domino" %}
{% set joueur2 = "threem" %}

### VIDEO ###
{% set youtube = "https://www.youtube.com/embed/X1wS_H-ay0Q" %}
{% set date = "29 mars 2022" %}

### LEGENDE ###
{% block pilote1 %}{{ pilote.domino() }}{% endblock %}
{% block deck1 %}{{ deck.card("/decks/aminatou-the-fateshifter") }}{% endblock %}
{% block deck2 %}{{ deck.card("/decks/tiamat") }}{% endblock %}
{% block pilote2 %}{{ pilote.threem() }}{% endblock %}
