{% extends "layout.html" %}

{% macro liste(dict, commentaire="", crop=needs_crop) %}
    {% for item in dict %}
        {% if item in crop %}
            {% set img = deck_name(item)|lower %}
            {% set img =  "img/split-crop/" + img + ".jpg" %}
        {% else %}
            {% set img = "" %}
        {% endif %}
        <div class="col-sm-4">
            {{ deck.card(item, img, commentaire) }}
        </div>
    {% endfor %}
{% endmacro %}

{% set archetype = request.args.get('l') or "" %}

{% block banner %}
<div class="barrins-codex-banner">
    Liste des decks
</div>
{% endblock %}

{% block article %}
<article class="col-8 ms-auto me-auto my-4">
    {% block ogdesc %}
    Liste des decks joués lors des soirées sur
    {{ external("https://www.twitch.tv/leschroniquesducommander", "<i class='fa-brands fa-twitch'></i> Twitch", _class="text-reset")}}.
    Une analyse et les parties jouées sont disponibles sur chaque page de deck.
    {% endblock %}
</article>

{% if (archetype == "") or (archetype == "agro") %}
<div class="col-12 bg-header py-4 mt-1 mb-2">
    <div class="col-8 ms-auto me-auto">
        <h2>Decks dont le macrotype est 🗡️ <em>Agro</em></h2>
    </div>
</div>
<article class="col-8 ms-auto me-auto my-4">
<div class="row py-3 d-flex flex-wrap justify-content-around">
    <div class="col-12">
        <strong>Agro</strong> représente la partie des decks dont le principal
        objectif est d'amener l'adversaire à zéro point de vie le plus
        rapidement possible en jouant des créatures ou des sorts de dégâts
        directs.
    </div>
    {{ liste(decks_agro) }}
</div>
</article>
{% endif %}
{% if archetype == "" %}
{{ separateur() }}
{% endif %}

{% if (archetype == "") or (archetype == "tempo") %}
<div class="col-12 bg-header py-4 mt-1 mb-2">
    <div class="col-8 ms-auto me-auto">
        <h2>Decks dont le macrotype est ⌚ <em>Tempo</em></h2>
    </div>
</div>
<article class="col-8 ms-auto me-auto my-4">
<div class="row py-3 d-flex flex-wrap justify-content-around">
    <div class="col-12">
        Les decks <strong>Tempo</strong> se reconnaissent à leur stratégie
        consistant à poser rapidement une ou plusieurs menaces puis à les
        protéger suffisamment longtemps, le plus souvent à l'aide de
        contresorts, pour gagner.
    </div>
    {{ liste(decks_tempo) }}
</div>
</article>
{% endif %}
{% if archetype == "" %}
{{ separateur() }}
{% endif %}

{% if (archetype == "") or (archetype == "controle") %}
<div class="col-12 bg-header py-4 mt-1 mb-2">
    <div class="col-8 ms-auto me-auto">
        <h2>Decks dont le macrotype est ⛓️ <em>Contrôle</em></h2>
    </div>
</div>
<article class="col-8 ms-auto me-auto my-4">
<div class="row py-3 d-flex flex-wrap justify-content-around">
    <div class="col-12">
        L'objectif des decks <strong>Contrôle</strong> est de ralentir le
        déroulement de la partie afin d'installer une guerre d'attrition basée
        essentiellement sur du <em>Card Advantage</em>.
    </div>
    {{ liste(decks_controle) }}
</div>
</article>
{% endif %}
{% if archetype == "" %}
{{ separateur() }}
{% endif %}

{% if (archetype == "") or (archetype == "combo") %}
<div class="col-12 bg-header py-4 mt-1 mb-2">
    <div class="col-8 ms-auto me-auto">
        <h2>Decks dont le macrotype est ✨ <em>Combo</em></h2>
    </div>
</div>
<article class="col-8 ms-auto me-auto my-4">
<div class="row py-3 d-flex flex-wrap justify-content-around">
    <div class="col-12">
        Les decks <strong>Combo</strong> sont basés sur une forte interaction
        entre au moins deux cartes (une <em>combinaison</em>) qui permet de
        gagner la partie instantanément ou qui mène à un très fort avantage
        quasi-synonyme de victoire.
    </div>
    {{ liste(decks_combo) }}
</div>
</article>
{% endif %}
{% if archetype == "" %}
{{ separateur() }}
{% endif %}

{% if (archetype == "") or (archetype == "midrange") %}
<div class="col-12 bg-header py-4 mt-1 mb-2">
    <div class="col-8 ms-auto me-auto">
        <h2>Decks dont le macrotype est 🦏 <em>Midrange</em></h2>
    </div>
</div>
<article class="col-8 ms-auto me-auto my-4">
<div class="row py-3 d-flex flex-wrap justify-content-around">
    <div class="col-12">
        Certains decks mélangent plusieurs stratégies, ce sont les decks
        <strong>Midrange</strong> qui se servent de sorts polyvalents pour
        naviguer dans la partie et alterner entre la posture d'agresseur et
        d'agressé avec la possibilité de clore la partie avec une combo ou une
        synergie forte.
    </div>
    {{ liste(decks_midrange) }}
</div>
</article>
{% endif %}
{% if archetype == "" %}
{{ separateur() }}
{% endif %}

{% if archetype == "" %}
<div class="col-12 bg-header py-4 mt-1 mb-2">
    <div class="col-8 ms-auto me-auto">
        <h2>Decks joués dont les généraux sont devenus illégaux</h2>
    </div>
</div>
<article class="col-8 ms-auto me-auto my-4">
<div class="row py-3 d-flex flex-wrap justify-content-around">
    {{ liste(decks_ban) }}
</div>
</article>
{% endif %}
{% endblock %}
