{% extends "decks/_layout_decks.html" %}

### PRESENTATION ###
{% block first_paragraph %}
    Ghyrson est un deck agressif. Plusieurs versions du deck cohabitent et
    explorent différents styles de jeu : du deck <em>burn</em> au deck
    <em>tempo</em> en passant par des stratégies basées sur les jetons, etc.
{% endblock %}
{% block second_paragraph %}
    La stratégie burn cherche à amasser le plus de dégâts avec le moins de
    cartes possibles tandis qu'une version tempo cherchera à diluer les dégâts
    et les sorts d'interaction comme {{ counterspell }} et {{ brazenborrower }}.
{% endblock %}
{% block third_paragraph %}
    Le dosage de cartes reposant sur le général est difficile à trouver et
    oscille entre dix et vingt selon les versions.
{% endblock %}


### LISTES ###
{% block liste %}
{{ decklist("https://www.moxfield.com/decks/GxNb6QH3IUKr3AHrJ1RKag") }}
{% endblock %}


### MATCHS ###
{% block matchs %}
{{ match.card2("/matchs/ghyrson-vs-nivmizzet", "Affrontement au somment contre un nouveau prétendant et un vieux dragon. Lequel des deux l'emportera ?") }}
{% endblock %}


### PILOTES ###
{% block pilotes %}
<div class="col-sm-4">
    {{ pilote.spigushe(played_on="06 décembre 2022") }}
</div>
{% endblock %}
