{% extends "decks/_layout_decks.html" %}

### PRESENTATION ###
{% block first_paragraph %}
    Principalement prison, Aminatou, the Fateshifter allie les contresorts à la
    gestion de permanents par des permanents faisant leur effet en entrant sur
    le champ de bataille. Cela permet d'utiliser au maximum la capacité de
    loyauté -1 du planeswalker.
{% endblock %}
{% block second_paragraph %}
    La qualité des cartes et la facilité à réutiliser certains effets rendent
    ce deck asphyxiant pour l'adversaire qui aura du mal à échapper à la prison
    que peut mettre en place Aminatou, the Fateshifter.
{% endblock %}
{% block third_paragraph %}
    Certaines versions du deck utilisent la combo {{ restinpeace }} et
    {{ helmofobedience }} pour avoir une possibilité de se sortir de situations
    qui mettent la partie en péril.
</p><p>
    La version « blink » capitalise sur les effets d'arrivée en jeu de
    créatures ; cette mécanique de départ-arrivée s'appelle « blink » du nom
    anglais de la carte qui a défini la stratégie : {{ momentaryblink }}.
{% endblock %}


### LISTES ###
{% block liste %}
{{ decklist("https://www.moxfield.com/decks/lq4K3B5ONk6iPvtsM_XZMA", "Deck contrôle par Spigushe")}}
{{ decklist("https://www.moxfield.com/decks/_4h58Y9250668NoEKHPn7Q", "Deck contrôle par threem")}}
{{ decklist("https://www.moxfield.com/decks/omiSLZPFVUSmxnCEj7_7Eg", "Version blink")}}
{% endblock %}


### MATCHS ###
{% block matchs %}
{{ match.card2("/matchs/aminatou-vs-klothys", "Match fréquent en tournoi, Aminatou est mis face à une version inhabituelle de Klothys. Est-ce toujours à l'avantage de la petite fille ?") }}
{{ match.card2("/matchs/aminatou-vs-tiamat", "Aminatou blink est un deck qui est de plus en plus fréquent en tournoi. Cette fois-ci, le deck est mis face à Tiamat, un deck contrôle et combo qui peut gagner à tout moment.") }}
{{ match.card2("/matchs/aminatou-vs-beamtown", "Aminatou version contrôle face à un challenger arrivé avec Streets of New Capenna. Qui des brutes ou de la petite fille remportera la victoire ?") }}
{% endblock %}


### PILOTES ###
{% block pilotes %}
<div class="col-sm-4">
    {{ pilote.spigushe(played_on="11 janvier 2022") }}
</div>
<div class="col-sm-4">
    {{ pilote.domino(played_on="29 mars 2022") }}
</div>
<div class="col-sm-4">
    {{ pilote.threem(played_on="10 mai 2022") }}
</div>
{% endblock %}
