{% extends "pilotes/_layout_pilotes.html" %}

{% set fichier="img/profile/Jules.png" %}
{% set name="Jules « Askeladden »" %}

### PRESENTATION ###
{% block first_paragraph %}{% endblock %}
{% block second_paragraph %}{% endblock %}
{% block third_paragraph %}{% endblock %}

### DECKS ###
{% block decks %}
<div class="row py-3 d-flex flex-wrap justify-content-around">
    <div class="col-sm-4">
        {{ deck.card("/decks/grist-the-hunger-tide") }}
    </div>
    <div class="col-sm-4">
        {{ deck.card("/decks/yoshimaru-ever-faithful", "img/split-crop/yoshimaru-naya.jpg") }}
    </div>
</div>
{% endblock %}

### MATCHS ###
{% block matchs %}
<div class="row py-3 d-flex flex-wrap justify-content-around">
    <div class="col-sm-4">
        {{ match.card("/matchs/grist-vs-raffine") }}
    </div>
    <div class="col-sm-4">
        {{ match.card("/matchs/leovold-vs-yoshimaru-naya") }}
    </div>
</div>
{% endblock %}
