{% extends "decks/_layout_decks.html" %}

### PRESENTATION ###
{% block first_paragraph %}
    Il s'agit d'un deck qui cherche à développer son mana en réduisant le mana
    disponible du côté adverse.
{% endblock %}
{% block second_paragraph %}
    Cette mécanique casse-terrains est viable dans une certaine mesure car le
    deck propose en parallèle des menaces assez fortes qui empêchent
    l'adversaire de reprendre l'ascendant dans la partie.
{% endblock %}
{% block third_paragraph %}
    De plus, mettre des cartes non-terrains en même temps que des cartes de
    terrains dans les cimetières permet d'utiliser au maximum la capacité de
    Klothys.
{% endblock %}


### LISTES ###
{% block liste %}
{{ decklist("https://www.moxfield.com/decks/2QS8dhRYWEOTZOj9tOdmIw") }}
{% endblock %}


### MATCHS ###
{% block matchs %}
{{ match.card2("/matchs/aminatou-vs-klothys", "Sixième match de la série, est-ce que Klothys sera en mesure d'empêcher le développement d'Aminatou ?") }}
{% endblock %}


### PILOTES ###
{% block pilotes %}
<div class="col-sm-4">
    {{ pilote.domino(played_on="11 janvier 2022") }}
</div>
{% endblock %}
