{% extends "matchs/_layout_matchs.html" %}

### PRESENTATION ###
{% block analyse %}
{% endblock %}


### JOUEURS ###
{% set joueur1 = "Aliquanto" %}
{% set joueur2 = "Threem" %}

### VIDEO ###
{% set youtube = "https://www.youtube.com/embed/thlsiUM9zO8" %}
{% set date = "5 juillet 2022" %}

### LEGENDE ###
{% block pilote1 %}{{ pilote.aliquanto() }}{% endblock %}
{% block deck1 %}{{ deck.card("/decks/azusa-lost-but-seeking") }}{% endblock %}
{% block deck2 %}{{ deck.card("/decks/elmarhargilde", "img/split-crop/elmar-hargilde.jpg") }}{% endblock %}
{% block pilote2 %}{{ pilote.threem() }}{% endblock %}
