{% extends "decks/_layout_decks.html" %}

### PRESENTATION ###
{% block first_paragraph %}
    L'archétype enchantress est populaire dans beaucoup de formats. La sortie
    de Sythis a permis de rendre l'archétype viable en Duel Commander.
{% endblock %}
{% block second_paragraph %}
    La majorité des cartes du deck sont des cartes qui empêchent l'adversaire
    de jouer ou de développer un plan de jeu trop rapidement.
{% endblock %}
{% block third_paragraph %}
    Sythis permet d'accéder continuellement à des cartes actives et enchaîner
    les sorts dès que le deck a accès à suffisamment de mana.
</p><p>
    {{ deck.ban("Serra\'s Sanctum", "La perte en explosivité ne rend pas le deck injouable mais peut le fragiliser dans certaines situations.") }}
{% endblock %}


### LISTES ###
{% block liste %}
{{ decklist("https://www.moxfield.com/decks/aoCFkSJkjU-DNpbJAI-QRQ") }}
{% endblock %}


### DECKTECH ###
{% block decktech %}
{{ deck.decktech(
    "https://www.youtube.com/embed/jRwthOwt2WQ?rel=0",
    "Deck tech faite par Adrien « Soullessoni » et publiée le 11 août 2021"
) }}
{% endblock %}


### MATCHS ###
{% block matchs %}
{{ match.card2("/matchs/grist-vs-sythis", "Proposé par les créateurs des deux listes jouées, ce match est exigeant des deux côtés de la table et les plays agressifs de Grist peuvent mettre Sythis en danger à tout moment.") }}
{% endblock %}


### PILOTES ###
{% block pilotes %}
<div class="col-sm-4">
    {{ pilote.spigushe(played_on="5 avril 2022") }}
</div>
{% endblock %}
