<li class="nav-item dropdown">
    <a class="nav-link dropdown-toggle" href="#" id="articlesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">📚 Articles</a>
    <ul class="dropdown-menu" aria-labelledby="matchDropdown">
        {{ liste(articles) }}
    </ul>
</li>
