{% extends "decks/_layout_decks.html" %}

### MODIFICATIONS PARTNER ###
{% block banner_img %}
{{ url_for('static', filename='img/split-crop/bjorna-wernog.jpg') }}
{% endblock %}

{% block commander %}
{{ deck.carousel_partner("Bjorna, Nightfall Alchemist", "Wernog, Rider's Chaplain") }}
{% endblock %}


### FRIENDS FOREVER ###
{% block friendsforever %}
<div class="col-12 bg-header py-4 mt-1 mb-2">
    <div class="col-8 ms-auto me-auto">
        <h2>Un changement de nom suite à la republication des cartes exclusives</h2>
    </div>
</div>
{{ deck.sld_rename('Stranger Things', 'Lucas, the Sharpshooter', 'Bjorna, Nightfall Alchemist') }}
{{ deck.sld_rename('Stranger Things', 'Will, the Wise', 'Wernog, Rider\'s Chaplain') }}
<div class="col-8 ms-auto me-auto">
    <div style="clear:both;"></div>
    <div class="w-100 border-bottom border-secondary border-opacity-50 border-2 mt-3"></div>
</div>
{% endblock %}


### PRESENTATION ###
{% block first_paragraph %}
    Il s'agit d'un deck contrôle capitalisant sur Lurrus of the Dream-Den pour
    gagner en récursivité et en redondance des menaces.
{% endblock %}
{% block second_paragraph %}
    Le deck, avec cette contrainte du compagnon, maximise les sorts
    d'interaction pour fatiguer l'adversaire et gagner la partie avec ses
    créatures.
{% endblock %}
{% block third_paragraph %}
    L'ajout de Lurrus en compagnon coûte au deck quelques cartes puissantes
    mais, dans l'ensemble, cela est compensé par la rejouabilité des cartes.
{{ deck.partner() }}
{% endblock %}


### LISTES ###
{% block liste %}
{{ decklist("https://www.moxfield.com/decks/0rlM-LQCEUOWytRaplQ") }}
{% endblock %}


### MATCHS ###
{% block matchs %}
{{ match.card2("/matchs/bjornawernog-vs-grist", "Ce match met en avant une partie de la demie-finale du ZAP mensuel ayant eu lieu le weekend précédent. Les deux decks ont des arbres de décision très complexes, lequel des deux pilotes remportera la victoire ?") }}
{% endblock %}


### PILOTES ###
{% block pilotes %}
<div class="col-sm-4">
    {{ pilote.imperia86(played_on="1er mars 2022") }}
</div>
{% endblock %}
